@@ -65,47 +65,47 @@ class CloudScraperWrapper(cloudscraper.CloudScraper):
 		# ------------------------------------------------------------------------------- #
 
 
-	def perform_request(self, method, url, *args, **kwargs):
-		assert args == (), "Args not empty! Value: %s" % (args, )
+	# def perform_request(self, method, url, *args, **kwargs):
+	# 	assert args == (), "Args not empty! Value: %s" % (args, )
 
-		if 'data' in kwargs and method != 'POST':
-			raise RuntimeError("Do not know how to handle post without data to post!")
-		# args seems to not be used
-		# Possible kwargs:
-		#     allow_redirects
-		#     data
-		#     headers
-		#     proxies
+	# 	if 'data' in kwargs and method != 'POST':
+	# 		raise RuntimeError("Do not know how to handle post without data to post!")
+	# 	# args seems to not be used
+	# 	# Possible kwargs:
+	# 	#     allow_redirects
+	# 	#     data
+	# 	#     headers
+	# 	#     proxies
 
 
-		print("perform_request")
-		print("method", method)
-		print("url", url)
-		print("args", args)
-		print("kwargs", kwargs)
+	# 	print("perform_request")
+	# 	print("method", method)
+	# 	print("url", url)
+	# 	print("args", args)
+	# 	print("kwargs", kwargs)
 
 
-		ret =  super(cloudscraper.CloudScraper, self).request(method, url, *args, **kwargs)
+	# 	ret =  super(cloudscraper.CloudScraper, self).request(method, url, *args, **kwargs)
 
 
-		self.wg.getfile
+	# 	self.wg.getfile
 
-		resp = requests.Response()
+	# 	resp = requests.Response()
 
-		resp._content = ""
-		resp._content_consumed = True
-		resp.status_code = None
-		resp.headers = requests.structures.CaseInsensitiveDict()
-		resp.raw = None
-		resp.url = None
-		resp.encoding = None
-		resp.history = []
-		resp.reason = None
-		resp.elapsed = datetime.timedelta(0)
-		resp.request = None
+	# 	resp._content = ""
+	# 	resp._content_consumed = True
+	# 	resp.status_code = None
+	# 	resp.headers = requests.structures.CaseInsensitiveDict()
+	# 	resp.raw = None
+	# 	resp.url = None
+	# 	resp.encoding = None
+	# 	resp.history = []
+	# 	resp.reason = None
+	# 	resp.elapsed = datetime.timedelta(0)
+	# 	resp.request = None
 
 
-		return ret
+	# 	return ret
 
 
 
