@@ -1126,8 +1126,13 @@ class WebGetRobust(
 
 
 	def stepThroughCloudFlareWaf(self, url:str):
-		return self.handle_cloudflare_cloudscraper(url)
-		# return self.stepThroughJsWaf(url, titleNotContains='Just a moment...')
+		try:
+			return self.handle_cloudflare_cloudscraper(url)
+		except Exception as e:
+			self.log.error("Failed in cloudscraper: %s", e)
+			self.log.error("Using JS tooling")
+
+			return self.stepThroughJsWaf(url, titleNotContains='Just a moment...')
 
 	def stepThroughSucuriWaf(self, url:str):
 		return self.stepThroughJsWaf(url, titleNotContains="You are being redirected...")
